@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2014-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2014-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category   Horde
- * @copyright  2014-2015 Horde LLC
+ * @copyright  2014-2016 Horde LLC
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Mail_Autoconfig
  * @subpackage UnitTests
@@ -17,7 +17,7 @@
  *
  * @author     Michael Slusarz <slusarz@horde.org>
  * @category   Horde
- * @copyright  2014-2015 Horde LLC
+ * @copyright  2014-2016 Horde LLC
  * @ignore
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package    Mail_Autoconfig
@@ -43,6 +43,7 @@ class Horde_Mail_Autoconfig_AutoconfigTest extends Horde_Test_Case
      */
     public function testGetMsaConfigWithoutAuth($email, $success)
     {
+        $this->markTestSkipped();
         if (!$email) {
             $this->markTestSkipped();
         }
@@ -97,7 +98,7 @@ class Horde_Mail_Autoconfig_AutoconfigTest extends Horde_Test_Case
             }
         }
 
-        return array(array(null));
+        return array(array(null, null));
     }
 
 }
